==> pmml-model-1.1.6-sources.jar: org/dmg/pmml/LiftGraph.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.jpmml.schema.Added;
import org.jpmml.schema.Version;
import org.xml.sax.Locator;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}XCoordinates"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}YCoordinates"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}BoundaryValues" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}BoundaryValueMeans" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "xCoordinates",
    "yCoordinates",
    "boundaryValues",
    "boundaryValueMeans"
})
@XmlRootElement(name = "LiftGraph", namespace = "http://www.dmg.org/PMML-4_2")
@Added(Version.PMML_4_0)
public class LiftGraph
    extends PMMLObject
    implements Locatable, HasExtensions
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_2")
    protected List<Extension> extensions;
    @XmlElement(name = "XCoordinates", namespace = "http://www.dmg.org/PMML-4_2", required = true)
    protected XCoordinates xCoordinates;
    @XmlElement(name = "YCoordinates", namespace = "http://www.dmg.org/PMML-4_2", required = true)
    protected YCoordinates yCoordinates;
    @XmlElement(name = "BoundaryValues", namespace = "http://www.dmg.org/PMML-4_2")
    protected BoundaryValues boundaryValues;
    @XmlElement(name = "BoundaryValueMeans", namespace = "http://www.dmg.org/PMML-4_2")
    protected BoundaryValueMeans boundaryValueMeans;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    public LiftGraph() {
        super();
    }

    public LiftGraph(final XCoordinates xCoordinates, final YCoordinates yCoordinates) {
        super();
        this.xCoordinates = xCoordinates;
        this.yCoordinates = yCoordinates;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the xCoordinates property.
     * 
     * @return
     *     possible object is
     *     {@link XCoordinates }
     *     
     */
    public XCoordinates getXCoordinates() {
        return xCoordinates;
    }

    /**
     * Sets the value of the xCoordinates property.
     * 
     * @param value
     *     allowed object is
     *     {@link XCoordinates }
     *     
     */
    public void setXCoordinates(XCoordinates value) {
        this.xCoordinates = value;
    }

    /**
     * Gets the value of the yCoordinates property.
     * 
     * @return
     *     possible object is
     *     {@link YCoordinates }
     *     
     */
    public YCoordinates getYCoordinates() {
        return yCoordinates;
    }

    /**
     * Sets the value of the yCoordinates property.
     * 
     * @param value
     *     allowed object is
     *     {@link YCoordinates }
     *     
     */
    public void setYCoordinates(YCoordinates value) {
        this.yCoordinates = value;
    }

    /**
     * Gets the value of the boundaryValues property.
     * 
     * @return
     *     possible object is
     *     {@link BoundaryValues }
     *     
     */
    public BoundaryValues getBoundaryValues() {
        return boundaryValues;
    }

    /**
     * Sets the value of the boundaryValues property.
     * 
     * @param value
     *     allowed object is
     *     {@link BoundaryValues }
     *     
     */
    public void setBoundaryValues(BoundaryValues value) {
        this.boundaryValues = value;
    }

    /**
     * Gets the value of the boundaryValueMeans property.
     * 
     * @return
     *     possible object is
     *     {@link BoundaryValueMeans }
     *     
     */
    public BoundaryValueMeans getBoundaryValueMeans() {
        return boundaryValueMeans;
    }

    /**
     * Sets the value of the boundaryValueMeans property.
     * 
     * @param value
     *     allowed object is
     *     {@link BoundaryValueMeans }
     *     
     */
    public void setBoundaryValueMeans(BoundaryValueMeans value) {
        this.boundaryValueMeans = value;
    }

    public LiftGraph withExtensions(Extension... values) {
        if (values!= null) {
            for (Extension value: values) {
                getExtensions().add(value);
            }
        }
        return this;
    }

    public LiftGraph withExtensions(Collection<Extension> values) {
        if (values!= null) {
            getExtensions().addAll(values);
        }
        return this;
    }

    public LiftGraph withXCoordinates(XCoordinates value) {
        setXCoordinates(value);
        return this;
    }

    public LiftGraph withYCoordinates(YCoordinates value) {
        setYCoordinates(value);
        return this;
    }

    public LiftGraph withBoundaryValues(BoundaryValues value) {
        setBoundaryValues(value);
        return this;
    }

    public LiftGraph withBoundaryValueMeans(BoundaryValueMeans value) {
        setBoundaryValueMeans(value);
        return this;
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        for (int i = 0; (((status == VisitorAction.CONTINUE)&&(this.extensions!= null))&&(i<this.extensions.size())); i ++) {
            status = this.extensions.get(i).accept(visitor);
        }
        if ((status == VisitorAction.CONTINUE)&&(this.xCoordinates!= null)) {
            status = this.xCoordinates.accept(visitor);
        }
        if ((status == VisitorAction.CONTINUE)&&(this.yCoordinates!= null)) {
            status = this.yCoordinates.accept(visitor);
        }
        if ((status == VisitorAction.CONTINUE)&&(this.boundaryValues!= null)) {
            status = this.boundaryValues.accept(visitor);
        }
        if ((status == VisitorAction.CONTINUE)&&(this.boundaryValueMeans!= null)) {
            status = this.boundaryValueMeans.accept(visitor);
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-1.2.0-sources.jar: org/dmg/pmml/LiftGraph.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jpmml.schema.Added;
import org.jpmml.schema.Version;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}XCoordinates"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}YCoordinates"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}BoundaryValues" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}BoundaryValueMeans" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "xCoordinates",
    "yCoordinates",
    "boundaryValues",
    "boundaryValueMeans"
})
@XmlRootElement(name = "LiftGraph", namespace = "http://www.dmg.org/PMML-4_2")
@Added(Version.PMML_4_0)
public class LiftGraph
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_2")
    private List<Extension> extensions;
    @XmlElement(name = "XCoordinates", namespace = "http://www.dmg.org/PMML-4_2", required = true)
    private XCoordinates xCoordinates;
    @XmlElement(name = "YCoordinates", namespace = "http://www.dmg.org/PMML-4_2", required = true)
    private YCoordinates yCoordinates;
    @XmlElement(name = "BoundaryValues", namespace = "http://www.dmg.org/PMML-4_2")
    private BoundaryValues boundaryValues;
    @XmlElement(name = "BoundaryValueMeans", namespace = "http://www.dmg.org/PMML-4_2")
    private BoundaryValueMeans boundaryValueMeans;

    public LiftGraph() {
        super();
    }

    public LiftGraph(final XCoordinates xCoordinates, final YCoordinates yCoordinates) {
        super();
        this.xCoordinates = xCoordinates;
        this.yCoordinates = yCoordinates;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the xCoordinates property.
     * 
     * @return
     *     possible object is
     *     {@link XCoordinates }
     *     
     */
    public XCoordinates getXCoordinates() {
        return xCoordinates;
    }

    /**
     * Sets the value of the xCoordinates property.
     * 
     * @param value
     *     allowed object is
     *     {@link XCoordinates }
     *     
     */
    public LiftGraph setXCoordinates(XCoordinates xCoordinates) {
        this.xCoordinates = xCoordinates;
        return this;
    }

    /**
     * Gets the value of the yCoordinates property.
     * 
     * @return
     *     possible object is
     *     {@link YCoordinates }
     *     
     */
    public YCoordinates getYCoordinates() {
        return yCoordinates;
    }

    /**
     * Sets the value of the yCoordinates property.
     * 
     * @param value
     *     allowed object is
     *     {@link YCoordinates }
     *     
     */
    public LiftGraph setYCoordinates(YCoordinates yCoordinates) {
        this.yCoordinates = yCoordinates;
        return this;
    }

    /**
     * Gets the value of the boundaryValues property.
     * 
     * @return
     *     possible object is
     *     {@link BoundaryValues }
     *     
     */
    public BoundaryValues getBoundaryValues() {
        return boundaryValues;
    }

    /**
     * Sets the value of the boundaryValues property.
     * 
     * @param value
     *     allowed object is
     *     {@link BoundaryValues }
     *     
     */
    public LiftGraph setBoundaryValues(BoundaryValues boundaryValues) {
        this.boundaryValues = boundaryValues;
        return this;
    }

    /**
     * Gets the value of the boundaryValueMeans property.
     * 
     * @return
     *     possible object is
     *     {@link BoundaryValueMeans }
     *     
     */
    public BoundaryValueMeans getBoundaryValueMeans() {
        return boundaryValueMeans;
    }

    /**
     * Sets the value of the boundaryValueMeans property.
     * 
     * @param value
     *     allowed object is
     *     {@link BoundaryValueMeans }
     *     
     */
    public LiftGraph setBoundaryValueMeans(BoundaryValueMeans boundaryValueMeans) {
        this.boundaryValueMeans = boundaryValueMeans;
        return this;
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public LiftGraph addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        visitor.pushParent(this);
        if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
            status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
        }
        XCoordinates xCoordinates = getXCoordinates();
        if ((status == VisitorAction.CONTINUE)&&(xCoordinates!= null)) {
            status = xCoordinates.accept(visitor);
        }
        YCoordinates yCoordinates = getYCoordinates();
        if ((status == VisitorAction.CONTINUE)&&(yCoordinates!= null)) {
            status = yCoordinates.accept(visitor);
        }
        BoundaryValues boundaryValues = getBoundaryValues();
        if ((status == VisitorAction.CONTINUE)&&(boundaryValues!= null)) {
            status = boundaryValues.accept(visitor);
        }
        BoundaryValueMeans boundaryValueMeans = getBoundaryValueMeans();
        if ((status == VisitorAction.CONTINUE)&&(boundaryValueMeans!= null)) {
            status = boundaryValueMeans.accept(visitor);
        }
        visitor.popParent();
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
